@@ -39,7 +39,7 @@ import os
 import sys
 import re
 import requests
-import Util
+from uo_vra_netdot_client import Util
 
 __version__ = "2.0"
 
